@@ -43,6 +43,8 @@ enum arithmetic_prog_operators
   ARITHMETIC_OP_INTERPOLATE_MINNGB,
   ARITHMETIC_OP_INTERPOLATE_MAXNGB,
   ARITHMETIC_OP_INTERPOLATE_MEDIANNGB,
+  ARITHMETIC_OP_INTERPOLATE_MINOFREGION,
+  ARITHMETIC_OP_INTERPOLATE_MAXOFREGION,
   ARITHMETIC_OP_COLLAPSE_SUM,
   ARITHMETIC_OP_COLLAPSE_MIN,
   ARITHMETIC_OP_COLLAPSE_MAX,
