@@ -32,6 +32,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/fits.h>
 #include <gnuastro/blank.h>
 #include <gnuastro/pointer.h>
+#include <gnuastro/statistics.h>
 
 #include <gnuastro-internal/timing.h>
 #include <gnuastro-internal/checkset.h>
@@ -305,10 +306,10 @@ fits_datasum(struct fitsparams *p)
 static void
 fits_pixelscale(struct fitsparams *p)
 {
-  size_t i, ndim;
-  double *pixelscale;
-  struct wcsprm *wcs;
   int nwcs=0;
+  size_t i, ndim=0;
+  struct wcsprm *wcs;
+  double multip, *pixelscale;
 
   /* Read the desired WCS. */
   wcs=gal_wcs_read(p->filename, p->cp.hdu, 0, 0, &nwcs);
@@ -333,15 +334,74 @@ fits_pixelscale(struct fitsparams *p)
              "with '--quiet' or '-q')\n");
       printf("  Input: %s (hdu %s) has %zu dimensions.\n", p->filename,
              p->cp.hdu, ndim);
-      printf("  Pixel scale in each dimension:\n");
+      printf("  Pixel scale in each FITS dimension:\n");
       for(i=0;i<ndim;++i)
-        printf("    %zu: %g (%s/pixel)\n", i+1, pixelscale[i], wcs->cunit[i]);
+        {
+          if( !strcmp(wcs->cunit[i], "deg") )
+            printf("    %zu: %g (%s/pixel) = %g (arcsec/pixel)\n", i+1,
+                   pixelscale[i], wcs->cunit[i], pixelscale[i]*3600);
+          else
+            printf("    %zu: %g (%s/slice)\n", i+1,
+                   pixelscale[i], wcs->cunit[i]);
+        }
+
+      /* Pixel area/volume. */
+      if(ndim>=2)
+        {
+          /* Multiply the values in each dimension. */
+          multip=pixelscale[0]*pixelscale[1];
+
+          /* Pixel scale (applicable to 2 or 3 dimensions). */
+          printf("  Pixel area%s:\n", ndim==2?"":" (on each 2D slice) ");
+          if( strcmp(wcs->cunit[0], wcs->cunit[1]) )
+            printf("    %g (%s*%s)\n", multip, wcs->cunit[0],
+                   wcs->cunit[1]);
+          else
+            if( strcmp(wcs->cunit[0], "deg") )
+              printf("    %g (%s^2)\n", multip, wcs->cunit[0]);
+            else
+              printf("    %g (deg^2) = %g (arcsec^2)\n",
+                     multip, multip*3600*3600 );
+
+          /* For a 3 dimensional dataset, we need need extra info. */
+          if(ndim>=3)
+            {
+              multip*=pixelscale[2];
+              printf("  Voxel volume:\n");
+              if( strcmp(wcs->cunit[0], wcs->cunit[1]) )
+                printf("    %g (%s*%s*%s)\n", multip, wcs->cunit[0],
+                       wcs->cunit[1], wcs->cunit[2]);
+              else
+                if( strcmp(wcs->cunit[0], "deg") )
+                  printf("    %g (%s^2*%s)\n", multip, wcs->cunit[0],
+                         wcs->cunit[2]);
+                else
+                  {
+                    if( strcmp(wcs->cunit[2], "m") )
+                      printf("    %g (deg^2*%s) = %g (arcsec^2*%s)\n",
+                             multip, wcs->cunit[2], multip*3600*3600,
+                             wcs->cunit[2]);
+                    else
+                      printf("    %g (deg^2*m) = %g (arcsec^2*m) = "
+                             "%g (arcsec^2*A)\n", multip, multip*3600*3600,
+                             multip*3600*3600*1e10);
+                  }
+            }
+        }
     }
   else
     {
-      for(i=0;i<ndim-1;++i)
-        printf("%g ", pixelscale[i]);
-      printf("%g\n", pixelscale[ndim-1]);
+      multip=1;
+      for(i=0;i<ndim;++i)
+        {
+          multip*=pixelscale[i];
+          printf("%g ", pixelscale[i]);
+        }
+      switch(ndim)
+        {
+        case 2: printf("%g\n", multip); break;
+        case 3: printf("%g %g\n", pixelscale[0]*pixelscale[1], multip); break;
+        }
     }
 
   /* Clean up. */
@@ -353,6 +413,75 @@ fits_pixelscale(struct fitsparams *p)
 
 
 
+static void
+fits_skycoverage(struct fitsparams *p)
+{
+  int nwcs=0;
+  size_t i, ndim;
+  struct wcsprm *wcs;
+  double *center, *width, *min, *max;
+
+  /* Find the coverage. */
+  if( gal_wcs_coverage(p->filename, p->cp.hdu, &ndim,
+                       &center, &width, &min, &max)==0 )
+    error(EXIT_FAILURE, 0, "%s (hdu %s): is not usable for finding "
+          "sky coverage (either doesn't have a WCS, or isn't an image "
+          "or cube HDU with 2 or 3 dimensions", p->filename, p->cp.hdu);
+
+  /* Inform the user. */
+  if(p->cp.quiet)
+    {
+      /* First print the center and full-width. */
+      for(i=0;i<ndim;++i) printf("%-15.10g ", center[i]);
+      for(i=0;i<ndim;++i) printf("%-15.10g ", width[i]);
+      printf("\n");
+
+      /* Then print the range in coordinates. */
+      for(i=0;i<ndim;++i) printf("%-15.10g %-15.10g ", min[i], max[i]);
+      printf("\n");
+    }
+  else
+    {
+      printf("Input file: %s (hdu: %s)\n", p->filename, p->cp.hdu);
+      printf("\nSky coverage by center and (full) width:\n");
+      switch(ndim)
+        {
+        case 2:
+          printf("  Center: %-15.10g%-15.10g\n", center[0], center[1]);
+          printf("  Width:  %-15.10g%-15.10g\n", width[0],  width[1]);
+          break;
+        case 3:
+          printf("  Center: %-15.10g%-15.10g%-15.10g\n", center[0],
+                 center[1], center[2]);
+          printf("  width:  %-15.10g%-15.10g%-15.10g\n", width[0],
+                 width[1], width[2]);
+          break;
+        default:
+          error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to fix "
+                "the problem. 'ndim' value %zu is not recognized", __func__,
+                PACKAGE_BUGREPORT, ndim);
+        }
+
+      /* For the range type of coverage. */
+      wcs=gal_wcs_read(p->filename, p->cp.hdu, 0, 0, &nwcs);
+      printf("\nSky coverage by range along dimensions:\n");
+      for(i=0;i<ndim;++i)
+        printf("  %-8s %-15.10g%-15.10g\n", gal_wcs_dimension_name(wcs, i),
+               min[i], max[i]);
+      wcsfree(wcs);
+    }
+
+  /* Clean up. */
+  free(min);
+  free(max);
+  free(width);
+  free(center);
+}
+
+
+
+
+
 static void
 fits_hdu_remove(struct fitsparams *p, int *r)
 {
@@ -483,6 +612,7 @@ fits(struct fitsparams *p)
       if(p->numhdus) fits_hdu_number(p);
       else if(p->datasum) fits_datasum(p);
       else if(p->pixelscale) fits_pixelscale(p);
+      else if(p->skycoverage) fits_skycoverage(p);
 
       /* Options that can be called together. */
       else
