@@ -70,13 +70,14 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
    the FITS standard (fastest dimension is first). */
 enum objectcols
   {
-    OCOL_NUMALL,         /* Number of all pixels with this label.     */
-    OCOL_NUMALLXY,       /* Number of all pixels in first two dims.   */
-    OCOL_NUM,            /* Number of values used in this object.     */
+    OCOL_NUMALL,         /* Area/number of all pixels with this label.*/
+    OCOL_NUMALLXY,       /* Area/Number in first two dimensions.      */
+    OCOL_NUM,            /* Area/Number of values used in this object.*/
     OCOL_NUMXY,          /* Number of values in the first two dims.   */
     OCOL_SUM,            /* Sum of (value-sky) in object.             */
     OCOL_SUM_VAR,        /* Variance including values (not just sky). */
-    OCOL_MEDIAN,         /* Median of value in object.                */
+    OCOL_MEDIAN,         /* Median of values in object.               */
+    OCOL_MAXIMUM,        /* Maximum value in object.                  */
     OCOL_SIGCLIPNUM,     /* Sigma-clipped mean of this object.        */
     OCOL_SIGCLIPSTD,     /* Sigma-clipped mean of this object.        */
     OCOL_SIGCLIPMEAN,    /* Sigma-clipped mean of this object.        */
@@ -87,6 +88,14 @@ enum objectcols
     OCOL_VXX,            /* Sum of (value-sky) * x * x.               */
     OCOL_VYY,            /* Sum of (value-sky) * y * y.               */
     OCOL_VXY,            /* Sum of (value-sky) * x * y.               */
+    OCOL_MINVX,          /* X of minimum pixel in values file.        */
+    OCOL_MAXVX,          /* X of maximum pixel in values file.        */
+    OCOL_MINVY,          /* Y of minimum pixel in values file.        */
+    OCOL_MAXVY,          /* Y of maximum pixel in values file.        */
+    OCOL_MINVZ,          /* Z of minimum pixel in values file.        */
+    OCOL_MAXVZ,          /* Z of maximum pixel in values file.        */
+    OCOL_MINVNUM,        /* Number of pixels with minimum value.      */
+    OCOL_MAXVNUM,        /* Number of pixels with maximum value.      */
     OCOL_SUMSKY,         /* Sum of sky value on this object.          */
     OCOL_NUMSKY,         /* Number of sky value on this object.       */
     OCOL_SUMVAR,         /* Sum of sky variance value on this object. */
@@ -103,6 +112,13 @@ enum objectcols
     OCOL_UPPERLIMIT_S,   /* Upper limit one-sigma value.              */
     OCOL_UPPERLIMIT_Q,   /* Quantile of object in random distribution.*/
     OCOL_UPPERLIMIT_SKEW,/* (Mean-Median)/STD of random distribution. */
+    OCOL_HALFMAXNUM,     /* Area/Number of pixels above half of max.  */
+    OCOL_HALFMAXSUM,     /* Sum of pixels above half of max.          */
+    OCOL_HALFSUMNUM,     /* Area/Number containing half of total sum. */
+    OCOL_FRACMAX1NUM,    /* Area/Number containing frac of maximum.   */
+    OCOL_FRACMAX1SUM,    /* Sum containing frac of maximum.           */
+    OCOL_FRACMAX2NUM,    /* Area/Number containing frac of maximum.   */
+    OCOL_FRACMAX2SUM,    /* Sum containing frac of maximum.           */
     OCOL_C_NUMALL,       /* Value independent no. of pixels in clumps.*/
     OCOL_C_NUM,          /* Area of clumps in this object.            */
     OCOL_C_SUM,          /* Brightness in object clumps.              */
@@ -127,6 +143,7 @@ enum clumpcols
     CCOL_SUM,            /* River subtracted brightness.              */
     CCOL_SUM_VAR,        /* Variance including values (not just sky). */
     CCOL_MEDIAN,         /* Median of values in clump.                */
+    CCOL_MAXIMUM,        /* Maximum value in clump.                   */
     CCOL_SIGCLIPNUM,     /* Sigma-clipped mean of this clump.         */
     CCOL_SIGCLIPSTD,     /* Sigma-clipped mean of this clump.         */
     CCOL_SIGCLIPMEAN,    /* Sigma-clipped mean of this clump.         */
@@ -140,6 +157,14 @@ enum clumpcols
     CCOL_VXX,            /* Sum of flux*x*x of this clump.            */
     CCOL_VYY,            /* Sum of flux*y*y of this clump.            */
     CCOL_VXY,            /* Sum of flux*x*y of this clump.            */
+    CCOL_MINVX,          /* X of minimum pixel in values array.       */
+    CCOL_MAXVX,          /* X of maximum pixel in values array.       */
+    CCOL_MINVY,          /* Y of minimum pixel in values array.       */
+    CCOL_MAXVY,          /* Y of maximum pixel in values array.       */
+    CCOL_MINVZ,          /* Z of minimum pixel in values array.       */
+    CCOL_MAXVZ,          /* Z of maximum pixel in values array.       */
+    CCOL_MINVNUM,        /* Number of pixels with minimum value.      */
+    CCOL_MAXVNUM,        /* Number of pixels with maximum value.      */
     CCOL_SUMSKY,         /* Sum of sky value on this clump.           */
     CCOL_NUMSKY,         /* Number of sky value on this clump.        */
     CCOL_SUMVAR,         /* Sum of sky variance value on this clump.  */
@@ -162,6 +187,13 @@ enum clumpcols
     CCOL_UPPERLIMIT_S,   /* Upper limit one-sigma value.              */
     CCOL_UPPERLIMIT_Q,   /* Quantile of object in random distribution.*/
     CCOL_UPPERLIMIT_SKEW,/* (Mean-Median)/STD of random distribution. */
+    CCOL_HALFMAXNUM,     /* Area/Number of pixels above half of max.  */
+    CCOL_HALFMAXSUM,     /* Sum of pixels above half of max.          */
+    CCOL_HALFSUMNUM,     /* Area/Number containing half of total sum. */
+    CCOL_FRACMAX1NUM,    /* Area/Number containing frac of maximum.   */
+    CCOL_FRACMAX1SUM,    /* Sum containing frac of maximum.           */
+    CCOL_FRACMAX2NUM,    /* Area/Number containing frac of maximum.   */
+    CCOL_FRACMAX2SUM,    /* Sum containing frac of maximum.           */
 
     CCOL_NUMCOLS,        /* SHOULD BE LAST: total number of columns.  */
   };
@@ -209,6 +241,8 @@ struct mkcatalogparams
   float              upnsigma;  /* Multiple of sigma to define up-lim.  */
   int32_t       checkuplim[2];  /* Object & clump ID to check dist.     */
 
+  gal_data_t         *fracmax;  /* Fractions to use in --fracsumarea.   */
+
   /* Internal. */
   char           *relabclumps;  /* Name of new file for clump labels.   */
   time_t              rawtime;  /* Starting time of the program.        */
@@ -221,6 +255,7 @@ struct mkcatalogparams
   float                medstd;  /* Median standard deviation value.     */
   float               cpscorr;  /* Counts-per-second correction.        */
   int32_t            *outlabs;  /* Labels in output catalog (when necessary) */
+  int32_t         *outlabsinv;  /* Inverse of the 'outlabs' array.      */
   size_t           numobjects;  /* Number of object labels in image.    */
   float               clumpsn;  /* Clump S/N threshold.                 */
   size_t            numclumps;  /* Number of clumps in image.           */
@@ -244,6 +279,7 @@ struct mkcatalogparams
   size_t         *numclumps_c;  /* To sort the clumps table by Obj.ID.  */
   gal_data_t   *specsliceinfo;  /* Slice information for spectra.       */
   gal_data_t         *spectra;  /* Array of datasets containing spectra.*/
+  double        pixelarcsecsq;  /* Area of input's pixels in arcsec^2.  */
 
   char        *usedvaluesfile;  /* Ptr to final name used for values.   */
   char        *usedclumpsfile;  /* Ptr to final name used for clumps.   */
