@@ -128,6 +128,7 @@ ui_initialize_options(struct mkcatalogparams *p,
   p->zeropoint      = NAN;
   p->sigmaclip[0]   = NAN;
   p->sigmaclip[1]   = NAN;
+  p->pixelarcsecsq  = NAN;
   p->upsigmaclip[0] = NAN;
   p->upsigmaclip[1] = NAN;
   p->checkuplim[0]  = GAL_BLANK_INT32;
@@ -361,8 +362,10 @@ static void
 ui_read_check_only_options(struct mkcatalogparams *p)
 {
   float tmp;
-  size_t one=1;
+  double *darr;
   char *tailptr;
+  size_t i, one=1;
+  gal_list_i32_t *colcode;
 
   /* If an upper-limit check table is requested with a specific clump, but
      no clump catalog has been requested, then abort and inform the
@@ -407,6 +410,38 @@ ui_read_check_only_options(struct mkcatalogparams *p)
           *((float *)(p->std->array))=tmp;
         }
     }
+
+  /* Make sure that '--fracmax' is given if necessary and that the fracsum
+     values are less than one. */
+  for(colcode=p->columnids; colcode!=NULL; colcode=colcode->next)
+    if( (colcode->v==UI_KEY_FRACMAXAREA1 || colcode->v==UI_KEY_FRACMAXAREA2)
+        && p->fracmax==NULL )
+      error(EXIT_FAILURE, 0, "please specify your required fractions for "
+            "'--fracmaxarea' using the '--fracmax' option (for example "
+            "'--fracmax=0.25,0.75' for two columns)");
+  if(p->fracmax)
+    {
+      /* Currently only 2 fracsums are accepted. */
+      if(p->fracmax->size>2)
+        error(EXIT_FAILURE, 0, "%zu values given to '--fracmax', only two "
+              "values are currently supported", p->fracmax->size);
+
+      /* Check the values. */
+      darr=p->fracmax->array;
+      for(i=0;i<p->fracmax->size;++i)
+        if(darr[i]<=0.0f || darr[i]>=1.0f)
+          error(EXIT_FAILURE, 0, "%g is not acceptable for '--fracmax', "
+                "values should be larger than 0 and less than 1", darr[i]);
+
+      /* If a second fracum column is necessary, make sure two values are
+         given to --fracmax. */
+      for(colcode=p->columnids; colcode!=NULL; colcode=colcode->next)
+        if(colcode->v==UI_KEY_FRACMAXAREA2 && p->fracmax->size==1)
+          error(EXIT_FAILURE, 0, "only one value given to '--fracmax', "
+                "but '--fracmaxarea2' was requested! You need to give "
+                "the requested fraction as a second value to '--fracmax', "
+                "separated by a comma (,)");
+    }
 }
 
 
@@ -537,6 +572,7 @@ ui_wcs_info(struct mkcatalogparams *p)
 static size_t
 ui_num_clumps(struct mkcatalogparams *p)
 {
+  int32_t olab;
   char *basename;
   int keepinputdir;
   size_t i, counter, numclumps=0;
@@ -558,13 +594,14 @@ ui_num_clumps(struct mkcatalogparams *p)
       if(*o>0 && *c>0)
         {
           /* See if the label has already been found. */
-          for(tmp=labsinobj[*o];tmp!=NULL;tmp=tmp->next) if(tmp->v==*c) break;
+          olab = p->outlabsinv ? p->outlabsinv[*o] : *o;
+          for(tmp=labsinobj[olab];tmp!=NULL;tmp=tmp->next) if(tmp->v==*c) break;
 
           /* When it wasn't found, 'tmp==NULL'. */
           if(tmp==NULL)
             {
               ++numclumps;
-              gal_list_i32_add(&labsinobj[*o], *c);
+              gal_list_i32_add(&labsinobj[olab], *c);
             }
         }
 
@@ -583,7 +620,8 @@ ui_num_clumps(struct mkcatalogparams *p)
       if(*o>0 && *c>0)
         {
           counter=0;
-          for(tmp=labsinobj[*o];tmp!=NULL;tmp=tmp->next)
+          olab = p->outlabsinv ? p->outlabsinv[*o] : *o;
+          for(tmp=labsinobj[olab];tmp!=NULL;tmp=tmp->next)
             { counter++; if(tmp->v==*c) {*c=counter; break;} }
         }
 
@@ -728,9 +766,25 @@ ui_one_tile_per_object_correct_numobjects(struct mkcatalogparams *p)
                                       "p->outlabs");
       for(i=0;i<p->numobjects;++i) if(rarray[i]==0) p->outlabs[j++]=i+1;
 
+      /* Allocate an array for easy finding of the proper label and fill it
+         with the new labels. This array should have an element for each of
+         the original labels (that are not contiguous). */
+      if(p->clumpscat)
+        {
+          p->outlabsinv=gal_pointer_allocate(GAL_TYPE_UINT32,
+                                             p->numobjects+1, 1,
+                                             __func__, "p->outlabsinv");
+          for(i=0;i<no;++i) p->outlabsinv[ p->outlabs[i] ] = i;
+        }
+
       /* Correct numobjects and clean up. */
       p->numobjects=no;
       gal_data_free(rowsremove);
+
+      /* For a check:
+      for(i=0;i<p->numobjects;++i)
+        printf("outlabs[%zu]: %d\n", i, p->outlabs[i]);
+      */
     }
 
   /* For a check.
@@ -786,6 +840,7 @@ ui_read_labels(struct mkcatalogparams *p)
           "is currently only defined on 3D datasets", p->objectsfile,
           p->cp.hdu, p->objects->ndim);
 
+
   /* See if the total number of objects is given in the header keywords. */
   keys[0].name="NUMLABS";
   keys[0].type=GAL_TYPE_SIZE_T;
@@ -798,6 +853,7 @@ ui_read_labels(struct mkcatalogparams *p)
       gal_data_free(tmp);
     }
 
+
   /* If there were no objects in the input, then inform the user with an
      error (it is pointless to build a catalog). */
   if(p->numobjects==0)
@@ -932,6 +988,7 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
         case OCOL_SUM:                *values        = 1;          break;
         case OCOL_SUM_VAR:            *values = *std = 1;          break;
         case OCOL_MEDIAN:             *values        = 1;          break;
+        case OCOL_MAXIMUM:            *values        = 1;          break;
         case OCOL_SIGCLIPNUM:         *values        = 1;          break;
         case OCOL_SIGCLIPMEDIAN:      *values        = 1;          break;
         case OCOL_SIGCLIPMEAN:        *values        = 1;          break;
@@ -942,6 +999,14 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
         case OCOL_VXX:                *values        = 1;          break;
         case OCOL_VYY:                *values        = 1;          break;
         case OCOL_VXY:                *values        = 1;          break;
+        case OCOL_MINVX:              *values        = 1;          break;
+        case OCOL_MAXVX:              *values        = 1;          break;
+        case OCOL_MINVY:              *values        = 1;          break;
+        case OCOL_MAXVY:              *values        = 1;          break;
+        case OCOL_MINVZ:              *values        = 1;          break;
+        case OCOL_MAXVZ:              *values        = 1;          break;
+        case OCOL_MINVNUM:            *values        = 1;          break;
+        case OCOL_MAXVNUM:            *values        = 1;          break;
         case OCOL_SUMSKY:             *sky           = 1;          break;
         case OCOL_SUMVAR:             *std           = 1;          break;
         case OCOL_SUMWHT:             *values        = 1;          break;
@@ -956,6 +1021,13 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
         case OCOL_UPPERLIMIT_S:       *values        = 1;          break;
         case OCOL_UPPERLIMIT_Q:       *values        = 1;          break;
         case OCOL_UPPERLIMIT_SKEW:    *values        = 1;          break;
+        case OCOL_HALFMAXNUM:         *values        = 1;          break;
+        case OCOL_HALFMAXSUM:         *values        = 1;          break;
+        case OCOL_HALFSUMNUM:         *values        = 1;          break;
+        case OCOL_FRACMAX1NUM:        *values        = 1;          break;
+        case OCOL_FRACMAX1SUM:        *values        = 1;          break;
+        case OCOL_FRACMAX2NUM:        *values        = 1;          break;
+        case OCOL_FRACMAX2SUM:        *values        = 1;          break;
         case OCOL_C_NUMALL:           /* Only clump labels.  */    break;
         case OCOL_C_NUM:              *values        = 1;          break;
         case OCOL_C_SUM:              *values        = 1;          break;
@@ -987,7 +1059,8 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
           case CCOL_SUM:              *values        = 1;          break;
           case CCOL_SUM_VAR:          *values = *std = 1;          break;
           case CCOL_MEDIAN:           *values        = 1;          break;
-          case CCOL_SIGCLIPNUM:    *values        = 1;          break;
+          case CCOL_MAXIMUM:          *values        = 1;          break;
+          case CCOL_SIGCLIPNUM:       *values        = 1;          break;
           case CCOL_SIGCLIPMEDIAN:    *values        = 1;          break;
           case CCOL_SIGCLIPMEAN:      *values        = 1;          break;
           case CCOL_SIGCLIPSTD:       *values        = 1;          break;
@@ -1000,6 +1073,14 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
           case CCOL_VXX:              *values        = 1;          break;
           case CCOL_VYY:              *values        = 1;          break;
           case CCOL_VXY:              *values        = 1;          break;
+          case CCOL_MINVX:            *values        = 1;          break;
+          case CCOL_MINVY:            *values        = 1;          break;
+          case CCOL_MINVZ:            *values        = 1;          break;
+          case CCOL_MAXVX:            *values        = 1;          break;
+          case CCOL_MAXVY:            *values        = 1;          break;
+          case CCOL_MAXVZ:            *values        = 1;          break;
+          case CCOL_MINVNUM:          *values        = 1;          break;
+          case CCOL_MAXVNUM:          *values        = 1;          break;
           case CCOL_SUMSKY:           *sky           = 1;          break;
           case CCOL_SUMVAR:           *std           = 1;          break;
           case CCOL_SUMWHT:           *values        = 1;          break;
@@ -1020,6 +1101,13 @@ ui_necessary_inputs(struct mkcatalogparams *p, int *values, int *sky,
           case CCOL_UPPERLIMIT_S:     *values        = 1;          break;
           case CCOL_UPPERLIMIT_Q:     *values        = 1;          break;
           case CCOL_UPPERLIMIT_SKEW:  *values        = 1;          break;
+          case CCOL_HALFMAXNUM:       *values        = 1;          break;
+          case CCOL_HALFMAXSUM:       *values        = 1;          break;
+          case CCOL_HALFSUMNUM:       *values        = 1;          break;
+          case CCOL_FRACMAX1NUM:      *values        = 1;          break;
+          case CCOL_FRACMAX1SUM:      *values        = 1;          break;
+          case CCOL_FRACMAX2NUM:      *values        = 1;          break;
+          case CCOL_FRACMAX2SUM:      *values        = 1;          break;
           default:
             error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to "
                   "fix the problem. The code %zu is not a recognized "
@@ -1922,6 +2010,7 @@ ui_free_report(struct mkcatalogparams *p, struct timeval *t1)
   gal_list_data_free(p->clumpcols);
   gal_list_data_free(p->objectcols);
   gal_list_data_free(p->specsliceinfo);
+  if(p->outlabsinv) free(p->outlabsinv);
   if(p->upcheckout) free(p->upcheckout);
   gal_data_array_free(p->tiles, p->numobjects, 0);
 
