@@ -3,9 +3,9 @@ MakeProfiles - Create mock astronomical profiles.
 MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -83,14 +83,40 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_SET,
       ui_parse_kernel
     },
+    {
+      "customtable",
+      UI_KEY_CUSTOMTABLE,
+      "STR",
+      0,
+      "File for 'custom' profile.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->customname,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "customtablehdu",
+      UI_KEY_CUSTOMTABLEHDU,
+      "INT/STR",
+      0,
+      "HDU of table given to '--customtable'.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->customhdu,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
 
 
 
 
 
     {
-      "naxis",
-      UI_KEY_NAXIS,
+      "mergedsize",
+      UI_KEY_MERGEDSIZE,
       "INT[,INT,...]",
       0,
       "Merged image size along each dimension.",
@@ -162,15 +188,15 @@ struct argp_option program_options[] =
     {
       0, 0, 0, 0,
       "Profiles:",
-      ARGS_GROUP_PROFILES
+      UI_GROUP_PROFILES
     },
     {
       "mode",
       UI_KEY_MODE,
       "STR",
       0,
-      "Mode of `--ccol': `img' or `wcs'.",
-      ARGS_GROUP_PROFILES,
+      "Mode of '--ccol': 'img' or 'wcs'.",
+      UI_GROUP_PROFILES,
       &p->mode,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -184,7 +210,7 @@ struct argp_option program_options[] =
       "INT",
       0,
       "No. of random points in Monte Carlo integration.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->numrandom,
       GAL_TYPE_SIZE_T,
       GAL_OPTIONS_RANGE_GT_0,
@@ -197,7 +223,7 @@ struct argp_option program_options[] =
       0,
       0,
       "Use GSL_RNG_SEED environment variable for seed.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->envseed,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -210,7 +236,7 @@ struct argp_option program_options[] =
       "FLT",
       0,
       "Tolerance to switch to less accurate method.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->tolerance,
       GAL_TYPE_FLOAT32,
       GAL_OPTIONS_RANGE_GE_0_LE_1,
@@ -223,7 +249,7 @@ struct argp_option program_options[] =
       0,
       0,
       "Truncation is in units of pixels, not radius.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->tunitinp,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -236,7 +262,7 @@ struct argp_option program_options[] =
       0,
       0,
       "mcol is flat pixel value (when fcol is 5 or 6)",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->mforflatpix,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -249,7 +275,7 @@ struct argp_option program_options[] =
       0,
       0,
       "mcol is total brightness, not magnitude.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->mcolisbrightness,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -262,7 +288,7 @@ struct argp_option program_options[] =
       "INT[, ...]",
       0,
       "Shift profile centers in output image.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->shift,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -276,7 +302,7 @@ struct argp_option program_options[] =
       0,
       0,
       "Shift and expand based on first catalog PSF.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->prepforconv,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -289,7 +315,7 @@ struct argp_option program_options[] =
       "FLT",
       0,
       "Magnitude zero point.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->zeropoint,
       GAL_TYPE_FLOAT32,
       GAL_OPTIONS_RANGE_ANY,
@@ -302,7 +328,7 @@ struct argp_option program_options[] =
       0,
       0,
       "Magnitude is for peak pixel, not full profile.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->magatpeak,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -315,7 +341,7 @@ struct argp_option program_options[] =
       "FLT",
       0,
       "Width of circumference (inward) profiles",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->circumwidth,
       GAL_TYPE_FLOAT32,
       GAL_OPTIONS_RANGE_GT_0,
@@ -328,7 +354,7 @@ struct argp_option program_options[] =
       0,
       0,
       "Replace overlapping profile pixels, don't add.",
-      ARGS_GROUP_PROFILES,
+      UI_GROUP_PROFILES,
       &p->replace,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
@@ -342,8 +368,8 @@ struct argp_option program_options[] =
 
     {
       0, 0, 0, 0,
-      "Columns, by info (see `--searchin'), or number (starting from 1):",
-      ARGS_GROUP_CATALOG
+      "Columns, by info (see '--searchin'), or number (starting from 1):",
+      UI_GROUP_CATALOG
     },
     {
       "ccol",
@@ -351,7 +377,7 @@ struct argp_option program_options[] =
       "STR/INT",
       0,
       "Coordinate columns (one call for each dimension).",
-      ARGS_GROUP_CATALOG,
+      UI_GROUP_CATALOG,
       &p->ccol,
       GAL_TYPE_STRLL,
       GAL_OPTIONS_RANGE_ANY,
@@ -364,8 +390,9 @@ struct argp_option program_options[] =
       "STR/INT",
       0,
       "sersic (1), moffat (2), gaussian (3), point (4), "
-      "flat (5), circumference (6), distance (7).",
-      ARGS_GROUP_CATALOG,
+      "flat (5), circumference (6), distance (7),"
+      "radial-table (8)",
+      UI_GROUP_CATALOG,
       &p->fcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -378,7 +405,7 @@ struct argp_option program_options[] =
       "STR/INT",
       0,
       "Effective radius or FWHM in pixels.",
-      ARGS_GROUP_CATALOG,
+      UI_GROUP_CATALOG,
       &p->rcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -391,7 +418,7 @@ struct argp_option program_options[] =
       "STR/INT",
       0,
       "Sersic index or Moffat beta.",
-      ARGS_GROUP_CATALOG,
+      UI_GROUP_CATALOG,
       &p->ncol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -403,34 +430,73 @@ struct argp_option program_options[] =
       UI_KEY_PCOL,
       "STR/INT",
       0,
-      "Position angle.",
-      ARGS_GROUP_CATALOG,
+      "Position angle (First X-Z-X Euler angle in 3D).",
+      UI_GROUP_CATALOG,
       &p->pcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+    {
+      "p2col",
+      UI_KEY_P2COL,
+      "STR/INT",
+      0,
+      "Second Euler angle (X-Z-X order).",
+      UI_GROUP_CATALOG,
+      &p->p2col,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "p3col",
+      UI_KEY_P2COL,
+      "STR/INT",
+      0,
+      "Third Euler angle (X-Z-X order).",
+      UI_GROUP_CATALOG,
+      &p->p3col,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
     {
       "qcol",
       UI_KEY_QCOL,
       "STR/INT",
       0,
-      "Axis ratio.",
-      ARGS_GROUP_CATALOG,
+      "Axis ratio (major/dim2 in 3D).",
+      UI_GROUP_CATALOG,
       &p->qcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+    {
+      "q2col",
+      UI_KEY_Q2COL,
+      "STR/INT",
+      0,
+      "Axis ratio (major/dim3 in 3D).",
+      UI_GROUP_CATALOG,
+      &p->q2col,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
     {
       "mcol",
       UI_KEY_MCOL,
       "STR/INT",
       0,
       "Magnitude.",
-      ARGS_GROUP_CATALOG,
+      UI_GROUP_CATALOG,
       &p->mcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -443,7 +509,7 @@ struct argp_option program_options[] =
       "STR/INT",
       0,
       "Truncation in units of --rcol, unless --tunitinp.",
-      ARGS_GROUP_CATALOG,
+      UI_GROUP_CATALOG,
       &p->tcol,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
@@ -458,7 +524,7 @@ struct argp_option program_options[] =
     {
       0, 0, 0, 0,
       "WCS parameters:",
-      ARGS_GROUP_WCS
+      UI_GROUP_WCS
     },
     {
       "crpix",
@@ -466,13 +532,13 @@ struct argp_option program_options[] =
       "FLT[, ...]",
       0,
       "Pixel coordinates of reference point.",
-      ARGS_GROUP_WCS,
+      UI_GROUP_WCS,
       &p->crpix,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET,
-      ui_parse_numbers
+      gal_options_parse_csv_float64
     },
     {
       "crval",
@@ -480,13 +546,13 @@ struct argp_option program_options[] =
       "FLT[, ...]",
       0,
       "WCS coordinates of reference point.",
-      ARGS_GROUP_WCS,
+      UI_GROUP_WCS,
       &p->crval,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET,
-      ui_parse_numbers
+      gal_options_parse_csv_float64
     },
     {
       "cdelt",
@@ -494,13 +560,13 @@ struct argp_option program_options[] =
       "FLT[, ...]",
       0,
       "Resolution in each dimension.",
-      ARGS_GROUP_WCS,
+      UI_GROUP_WCS,
       &p->cdelt,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET,
-      ui_parse_numbers
+      gal_options_parse_csv_float64
     },
     {
       "pc",
@@ -508,21 +574,21 @@ struct argp_option program_options[] =
       "FLT[, ...]",
       0,
       "WCS rotation matrix (all elements).",
-      ARGS_GROUP_WCS,
+      UI_GROUP_WCS,
       &p->pc,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET,
-      ui_parse_numbers
+      gal_options_parse_csv_float64
     },
     {
       "cunit",
       UI_KEY_CUNIT,
       "STR[, ... ]",
       0,
-      "Units of the WCS coordinates (e.g., `deg').",
-      ARGS_GROUP_WCS,
+      "Units of the WCS coordinates (e.g., 'deg').",
+      UI_GROUP_WCS,
       &p->cunit,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
@@ -536,7 +602,7 @@ struct argp_option program_options[] =
       "STR[, ... ]",
       0,
       "One of FITS standard WCS types.",
-      ARGS_GROUP_WCS,
+      UI_GROUP_WCS,
       &p->ctype,
       GAL_TYPE_FLOAT64,
       GAL_OPTIONS_RANGE_ANY,
