@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -66,6 +66,7 @@ enum profile_types
   PROFILE_FLAT,                 /* Flat profile.               */
   PROFILE_CIRCUMFERENCE,        /* Circumference profile.      */
   PROFILE_DISTANCE,             /* Elliptical radius of pixel. */
+  PROFILE_CUSTOM,          /* Radial prof. in file/table. */
 
   PROFILE_MAXIMUM_CODE,         /* Just for a sanity check.    */
 };
@@ -114,6 +115,8 @@ struct mkprofparams
   char            *backname;  /* Name of background image file name.      */
   char             *catname;  /* Name of catalog of parameters.           */
   char             *backhdu;  /* HDU of background image.                 */
+  char          *customname;  /* Table to use for radial profile.         */
+  char           *customhdu;  /* HDU of table to use for radial profile.  */
   size_t             *dsize;  /* Size of the output image.                */
   uint8_t       clearcanvas;  /* Pixels in background image set to zero.  */
   gal_data_t        *kernel;  /* Parameters to define a kernel.           */
@@ -137,12 +140,15 @@ struct mkprofparams
   char                *fcol;  /* Column specifying profile function.      */
   char                *rcol;  /* Effective radius of profile.             */
   char                *ncol;  /* Sersic index column of profile.          */
-  char                *pcol;  /* Position angle column of profile.        */
-  char                *qcol;  /* Axis ratio column of profile.            */
+  char                *pcol;  /* First Euler angle (X-Z-X order).         */
+  char               *p2col;  /* Second Euler angle (X-Z-X order).        */
+  char               *p3col;  /* Third Euler angle (X-Z-X order).         */
+  char                *qcol;  /* Axis ratio1 (major/2nd dim. radius).     */
+  char               *q2col;  /* Axis ratio2 (major/3rd dim. radius).     */
   char                *mcol;  /* Magnitude column.                        */
   char                *tcol;  /* Truncation of the profiles.              */
   uint8_t       mforflatpix;  /* mcol is flat pixel value (f is 4 or 5).  */
-  uint8_t  mcolisbrightness;  /* mcol is total brightness not magnitude.  */
+  uint8_t  mcolisbrightness;  /* mcol is total brightness, not magnitude. */
   gal_data_t         *crpix;  /* CRPIX FITS header keywords.              */
   gal_data_t         *crval;  /* CRVAL FITS header keywords.              */
   gal_data_t         *cdelt;  /* For CDELTi FITS header keywords.         */
@@ -161,11 +167,15 @@ struct mkprofparams
   size_t                num;  /* The number of profiles.                  */
   double                 *x;  /* X axis position of profile center.       */
   double                 *y;  /* Y axis position of profile center.       */
+  double                 *z;  /* Z axis position of profile center.       */
   uint8_t                *f;  /* Profile function code.                   */
   float                  *r;  /* Radius of profile.                       */
   float                  *n;  /* Index of profile.                        */
-  float                  *p;  /* Position angle of profile.               */
-  float                  *q;  /* Axis ratio of profile.                   */
+  float                 *p1;  /* First Euler angle (X-Z-X order).         */
+  float                 *p2;  /* Second Euler angle (X-Z-X order).        */
+  float                 *p3;  /* Third Euler angle (X-Z-X order).         */
+  float                 *q1;  /* Ratio of radius to second axis.          */
+  float                 *q2;  /* Ratio of radius to third axis.           */
   float                  *m;  /* Magnitude of profile.                    */
   float                  *t;  /* Truncation distance.                     */
   gsl_rng              *rng;  /* Main instance of random number generator.*/
@@ -181,10 +191,12 @@ struct mkprofparams
   char           *wcsheader;  /* The WCS header information for main img. */
   int            wcsnkeyrec;  /* The number of keywords in the WCS header.*/
   char       *mergedimgname;  /* Name of merged image.                    */
+  gal_data_t        *custom;  /* Table containing custom values.          */
+  double   customregular[2];  /* Non-NaN if input table is regular.       */
   int                  nwcs;  /* for WCSLIB: no. coord. representations.  */
   struct wcsprm        *wcs;  /* WCS information for this dataset.        */
-  size_t               ndim;  /* Number of dimensions (for `nomerged').   */
-                              /* We can't put it in `out' because it is   */
+  size_t               ndim;  /* Number of dimensions (for 'nomerged').   */
+                              /* We can't put it in 'out' because it is   */
                               /* meaning ful there.                       */
 };
 
