@@ -632,7 +632,7 @@ mkprof_write(struct mkprofparams *p)
          array. */
       if(ibq->overlaps && out)
         GAL_TILE_PO_OISET(float,float,ibq->overlap_i,ibq->overlap_m,1,0, {
-            *o  = p->replace ? ( *i==0.0f ? *o : *i ) :  (*i + *o);
+            *o  = p->replace ? ( *i>*o ? *i : *o ) :  (*i + *o);
             sum += *i;
           });
 
@@ -749,12 +749,12 @@ mkprof(struct mkprofparams *p)
 {
   char *tmp;
   pthread_t t;            /* Thread id not used, all are saved here. */
-  int err, origquiet;
   pthread_attr_t attr;
   pthread_barrier_t b;
   size_t numforprint=50;
   struct mkonthread *mkp;
   gal_list_str_t *comments=NULL;
+  int err, origquiet=p->cp.quiet;
   size_t i, fi, *indexs, thrdcols;
   long *onaxes=NULL, os=p->oversample;
   size_t nb, ndim=p->ndim, nt=p->cp.numthreads;
@@ -842,7 +842,6 @@ mkprof(struct mkprofparams *p)
         printf("  ---- Building %zu profiles... ", p->num);
 
       /* Disable the quiet flag.*/
-      origquiet=p->cp.quiet;
       p->cp.quiet=1;
     }
 
