@@ -3,9 +3,9 @@ MakeProfiles - Create mock astronomical profiles.
 MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -24,33 +24,39 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #define PROFILES_H
 
 double
-Gaussian(struct mkonthread *mkp);
+profiles_radial_distance(struct mkonthread *mkp);
 
 double
-totgaussian(double q);
+profiles_custom_table(struct mkonthread *mkp);
 
 double
-Moffat(struct mkonthread *mkp);
+profiles_gaussian_total(double q);
 
 double
-moffat_alpha(double fwhm, double beta);
+profiles_gaussian(struct mkonthread *mkp);
 
 double
-totmoffat(double alpha, double beta, double q);
+profiles_moffat_alpha(double fwhm, double beta);
 
 double
-Sersic(struct mkonthread *mkp);
+profiles_moffat_total(double alpha, double beta, double q);
 
 double
-sersic_b(double n);
+profiles_moffat(struct mkonthread *mkp);
 
 double
-totsersic(double n, double re, double b, double q);
+profiles_sersic_b(double n);
 
 double
-Circumference(struct mkonthread *mkp);
+profiles_sersic_total(double n, double re, double b, double q);
 
 double
-Flat(struct mkonthread *mkp);
+profiles_sersic(struct mkonthread *mkp);
+
+double
+profiles_circumference(struct mkonthread *mkp);
+
+double
+profiles_flat(struct mkonthread *mkp);
 
 #endif
