@@ -801,7 +801,7 @@ segment_save_sn_table(struct clumps_params *clprm)
   /* Set the column pointers and write them into a table.. */
   clumpinobj->next=sn;
   objind->next=clumpinobj;
-  gal_table_write(objind, comments, p->cp.tableformat, p->clumpsn_d_name,
+  gal_table_write(objind, NULL, comments, p->cp.tableformat, p->clumpsn_d_name,
                   "DET_CLUMP_SN", 0);
 
 
@@ -824,6 +824,54 @@ segment_save_sn_table(struct clumps_params *clprm)
 
 
 
+/* Avoid non-reproducible labels (when built on multiple threads). Note
+   that when working with objects, the clump labels don't need to be
+   re-labeled (they always start from 1 within each object and are thus
+   already thread-safe).*/
+static void
+segment_reproducible_labels(struct segmentparams *p)
+{
+  size_t i;
+  gal_data_t *new;
+  int32_t currentlab=0, *oldarr, *newarr, *newlabs;
+  gal_data_t *old = p->onlyclumps ? p->clabel : p->olabel;
+  size_t numlabsplus1 = (p->onlyclumps ? p->numclumps : p->numobjects) + 1;
+
+  /* Allocate the necessary datasets. */
+  new=gal_data_alloc(NULL, old->type, old->ndim, old->dsize, old->wcs, 0,
+                     p->cp.minmapsize, p->cp.quietmmap, old->name, old->unit,
+                     old->comment);
+  newlabs=gal_pointer_allocate(old->type, numlabsplus1, 0, __func__,
+                               "newlabs");
+
+  /* Initialize the newlabs array to blank (so we don't relabel
+     things). */
+  for(i=0;i<numlabsplus1;++i) newlabs[i]=GAL_BLANK_INT32;
+
+  /* Parse the old dataset and set the new labels. */
+  oldarr=old->array;
+  for(i=0;i<old->size;++i)
+    if( oldarr[i] > 0 && newlabs[ oldarr[i] ]==GAL_BLANK_INT32 )
+      newlabs[ oldarr[i] ] = ++currentlab;
+
+  /* For a check.
+  for(i=0;i<numlabsplus1;++i) printf("%zu --> %d\n", i, newlabs[i]);
+  */
+
+  /* Fill the newly labeled dataset. */
+  newarr=new->array;
+  for(i=0;i<old->size;++i)
+    newarr[i] = oldarr[i]>0 ? newlabs[ oldarr[i] ] : oldarr[i];
+
+  /* Clean up. */
+  free(newlabs);
+  if(p->onlyclumps) { gal_data_free(p->clabel); p->clabel=new; }
+  else              { gal_data_free(p->olabel); p->olabel=new; }
+}
+
+
+
+
 /* Find true clumps over the detected regions. */
 static void
 segment_detections(struct segmentparams *p)
@@ -1028,6 +1076,13 @@ segment_detections(struct segmentparams *p)
   p->numobjects=clprm.totobjects;
 
 
+  /* Correct the final object labels to start from the bottom of the
+     image. This is necessary because we define objects on multiple
+     threads, so every time a program is run, an object can have a
+     different label! */
+  segment_reproducible_labels(p);
+
+
   /* Clean up allocated structures and destroy the mutex. */
   gal_data_array_free(clprm.sn, p->numdetections+1, 1);
   gal_data_array_free(labindexs, p->numdetections+1, 1);
@@ -1070,10 +1125,10 @@ segment_output(struct segmentparams *p)
   /* The clump labels. */
   gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "CLUMPSN", 0,
                         &p->clumpsnthresh, 0, "Minimum S/N of true clumps",
-                        0, "ratio");
+                        0, "ratio", 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_SIZE_T, "NUMLABS", 0,
                         &p->numclumps, 0, "Total number of clumps", 0,
-                        "counter");
+                        "counter", 0);
   p->clabel->name="CLUMPS";
   gal_fits_img_write(p->clabel, p->cp.output, keys, PROGRAM_NAME);
   p->clabel->name=NULL;
@@ -1085,7 +1140,7 @@ segment_output(struct segmentparams *p)
     {
       gal_fits_key_list_add(&keys, GAL_TYPE_SIZE_T, "NUMLABS", 0,
                             &p->numobjects, 0, "Total number of objects", 0,
-                            "counter");
+                            "counter", 0);
       p->olabel->name="OBJECTS";
       gal_fits_img_write(p->olabel, p->cp.output, keys, PROGRAM_NAME);
       p->olabel->name=NULL;
@@ -1101,17 +1156,17 @@ segment_output(struct segmentparams *p)
         gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "MAXSTD", 0,
                               &p->maxstd, 0,
                               "Maximum raw tile standard deviation", 0,
-                              p->input->unit);
+                              p->input->unit, 0);
       if( !isnan(p->minstd) )
         gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "MINSTD", 0,
                               &p->minstd, 0,
                               "Minimum raw tile standard deviation", 0,
-                              p->input->unit);
+                              p->input->unit, 0);
       if( !isnan(p->medstd) )
         gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "MEDSTD", 0,
                               &p->medstd, 0,
                               "Median raw tile standard deviation", 0,
-                              p->input->unit);
+                              p->input->unit, 0);
 
       /* If the input was actually a variance dataset, we'll need to take
          its square root before writing it. We want this output to be a
