@@ -34,14 +34,15 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 /* Configuration macros: */
 
-#define GAL_CONFIG_VERSION                  "0.12.37-5018"
+#define GAL_CONFIG_VERSION                  "0.13.50-4605"
 
 #define GAL_CONFIG_HAVE_LIBGIT2             yes
 
-#define GAL_CONFIG_HAVE_FITS_IS_REENTRANT   @HAVE_FITS_IS_REENTRANT@
+#define GAL_CONFIG_HAVE_FITS_IS_REENTRANT   1
 #define GAL_CONFIG_HAVE_WCSLIB_VERSION      1
 #define GAL_CONFIG_HAVE_WCSLIB_DIS_H        1
 #define GAL_CONFIG_HAVE_WCSLIB_MJDREF       1
+#define GAL_CONFIG_HAVE_WCSLIB_OBSFIX       1
 
 #define GAL_CONFIG_HAVE_PTHREAD_BARRIER     1
 
