@@ -48,11 +48,11 @@ gal_speclines_line_name(int linecode)
     case GAL_SPECLINES_NII:              return GAL_SPECLINES_NAME_NII;
     case GAL_SPECLINES_HALPHA:           return GAL_SPECLINES_NAME_HALPHA;
     case GAL_SPECLINES_NIIBLUE:          return GAL_SPECLINES_NAME_NIIBLUE;
-    case GAL_SPECLINES_OIIIRED:          return GAL_SPECLINES_NAME_OIIIRED;
-    case GAL_SPECLINES_OIII:             return GAL_SPECLINES_NAME_OIII;
-    case GAL_SPECLINES_OIIIBLUE:         return GAL_SPECLINES_NAME_OIIIBLUE;
+    case GAL_SPECLINES_OIIIRED_VIS:      return GAL_SPECLINES_NAME_OIIIRED_VIS;
+    case GAL_SPECLINES_OIII_VIS:         return GAL_SPECLINES_NAME_OIII_VIS;
+    case GAL_SPECLINES_OIIIBLUE_VIS:     return GAL_SPECLINES_NAME_OIIIBLUE_VIS;
     case GAL_SPECLINES_HBETA:            return GAL_SPECLINES_NAME_HBETA;
-    case GAL_SPECLINES_HEIIRED:          return GAL_SPECLINES_NAME_HEIIRED;
+    case GAL_SPECLINES_HEII_VIS:         return GAL_SPECLINES_NAME_HEII_VIS;
     case GAL_SPECLINES_HGAMMA:           return GAL_SPECLINES_NAME_HGAMMA;
     case GAL_SPECLINES_HDELTA:           return GAL_SPECLINES_NAME_HDELTA;
     case GAL_SPECLINES_HEPSILON:         return GAL_SPECLINES_NAME_HEPSILON;
@@ -67,10 +67,24 @@ gal_speclines_line_name(int linecode)
     case GAL_SPECLINES_CIIIRED:          return GAL_SPECLINES_NAME_CIIIRED;
     case GAL_SPECLINES_CIII:             return GAL_SPECLINES_NAME_CIII;
     case GAL_SPECLINES_CIIIBLUE:         return GAL_SPECLINES_NAME_CIIIBLUE;
-    case GAL_SPECLINES_HEIIBLUE:         return GAL_SPECLINES_NAME_HEIIBLUE;
+    case GAL_SPECLINES_SiIIIRED:         return GAL_SPECLINES_NAME_SiIIIRED;
+    case GAL_SPECLINES_SiIII:            return GAL_SPECLINES_NAME_SiIII;
+    case GAL_SPECLINES_SiIIIBLUE:        return GAL_SPECLINES_NAME_SiIIIBLUE;
+    case GAL_SPECLINES_OIIIRED_UV:       return GAL_SPECLINES_NAME_OIIIRED_UV;
+    case GAL_SPECLINES_OIII_UV:          return GAL_SPECLINES_NAME_OIII_UV;
+    case GAL_SPECLINES_OIIIBLUE_UV:      return GAL_SPECLINES_NAME_OIIIBLUE_UV;
+    case GAL_SPECLINES_HEII_UV:          return GAL_SPECLINES_NAME_HEII_UV;
+    case GAL_SPECLINES_CIVRED:           return GAL_SPECLINES_NAME_CIVRED;
+    case GAL_SPECLINES_CIV:              return GAL_SPECLINES_NAME_CIV;
+    case GAL_SPECLINES_CIVBLUE:          return GAL_SPECLINES_NAME_CIVBLUE;
+    case GAL_SPECLINES_NV:               return GAL_SPECLINES_NAME_NV;
     case GAL_SPECLINES_LYALPHA:          return GAL_SPECLINES_NAME_LYALPHA;
+    case GAL_SPECLINES_LYBETA:           return GAL_SPECLINES_NAME_LYBETA;
+    case GAL_SPECLINES_LYGAMMA:          return GAL_SPECLINES_NAME_LYGAMMA;
+    case GAL_SPECLINES_LYDELTA:          return GAL_SPECLINES_NAME_LYDELTA;
+    case GAL_SPECLINES_LYEPSILON:        return GAL_SPECLINES_NAME_LYEPSILON;
     case GAL_SPECLINES_LYLIMIT:          return GAL_SPECLINES_NAME_LYLIMIT;
-    default:                           return NULL;
+    default: return NULL;
     }
   return NULL;
 }
@@ -97,16 +111,16 @@ gal_speclines_line_code(char *name)
     return GAL_SPECLINES_HALPHA;
   else if( !strcmp(name, GAL_SPECLINES_NAME_NIIBLUE) )
     return GAL_SPECLINES_NIIBLUE;
-  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIRED) )
-    return GAL_SPECLINES_OIIIRED;
-  else if( !strcmp(name, GAL_SPECLINES_NAME_OIII) )
-    return GAL_SPECLINES_OIII;
-  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIBLUE) )
-    return GAL_SPECLINES_OIIIBLUE;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIRED_VIS) )
+    return GAL_SPECLINES_OIIIRED_VIS;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIII_VIS) )
+    return GAL_SPECLINES_OIII_VIS;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIBLUE_VIS) )
+    return GAL_SPECLINES_OIIIBLUE_VIS;
   else if( !strcmp(name, GAL_SPECLINES_NAME_HBETA) )
     return GAL_SPECLINES_HBETA;
-  else if( !strcmp(name, GAL_SPECLINES_NAME_HEIIRED) )
-    return GAL_SPECLINES_HEIIRED;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_HEII_VIS) )
+    return GAL_SPECLINES_HEII_VIS;
   else if( !strcmp(name, GAL_SPECLINES_NAME_HGAMMA) )
     return GAL_SPECLINES_HGAMMA;
   else if( !strcmp(name, GAL_SPECLINES_NAME_HDELTA) )
@@ -135,10 +149,38 @@ gal_speclines_line_code(char *name)
     return GAL_SPECLINES_CIII;
   else if( !strcmp(name, GAL_SPECLINES_NAME_CIIIBLUE) )
     return GAL_SPECLINES_CIIIBLUE;
-  else if( !strcmp(name, GAL_SPECLINES_NAME_HEIIBLUE) )
-    return GAL_SPECLINES_HEIIBLUE;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_SiIIIRED) )
+    return GAL_SPECLINES_SiIIIRED;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_SiIII) )
+    return GAL_SPECLINES_SiIII;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_SiIIIBLUE) )
+    return GAL_SPECLINES_SiIIIBLUE;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIRED_UV) )
+    return GAL_SPECLINES_OIIIRED_UV;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIII_UV) )
+    return GAL_SPECLINES_OIII_UV;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_OIIIBLUE_UV) )
+    return GAL_SPECLINES_OIIIBLUE_UV;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_HEII_UV) )
+    return GAL_SPECLINES_HEII_UV;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_CIVRED) )
+    return GAL_SPECLINES_CIVRED;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_CIV) )
+    return GAL_SPECLINES_CIV;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_CIVBLUE) )
+    return GAL_SPECLINES_CIVBLUE;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_NV) )
+    return GAL_SPECLINES_NV;
   else if( !strcmp(name, GAL_SPECLINES_NAME_LYALPHA) )
     return GAL_SPECLINES_LYALPHA;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_LYBETA) )
+    return GAL_SPECLINES_LYBETA;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_LYGAMMA) )
+    return GAL_SPECLINES_LYGAMMA;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_LYDELTA) )
+    return GAL_SPECLINES_LYDELTA;
+  else if( !strcmp(name, GAL_SPECLINES_NAME_LYEPSILON) )
+    return GAL_SPECLINES_LYEPSILON;
   else if( !strcmp(name, GAL_SPECLINES_NAME_LYLIMIT) )
     return GAL_SPECLINES_LYLIMIT;
   else return GAL_SPECLINES_INVALID;
@@ -162,11 +204,11 @@ gal_speclines_line_angstrom(int linecode)
     case GAL_SPECLINES_NII:           return GAL_SPECLINES_ANGSTROM_NII;
     case GAL_SPECLINES_HALPHA:        return GAL_SPECLINES_ANGSTROM_HALPHA;
     case GAL_SPECLINES_NIIBLUE:       return GAL_SPECLINES_ANGSTROM_NIIBLUE;
-    case GAL_SPECLINES_OIIIRED:       return GAL_SPECLINES_ANGSTROM_OIIIRED;
-    case GAL_SPECLINES_OIII:          return GAL_SPECLINES_ANGSTROM_OIII;
-    case GAL_SPECLINES_OIIIBLUE:      return GAL_SPECLINES_ANGSTROM_OIIIBLUE;
+    case GAL_SPECLINES_OIIIRED_VIS:   return GAL_SPECLINES_ANGSTROM_OIIIRED_VIS;
+    case GAL_SPECLINES_OIII_VIS:      return GAL_SPECLINES_ANGSTROM_OIII_VIS;
+    case GAL_SPECLINES_OIIIBLUE_VIS:  return GAL_SPECLINES_ANGSTROM_OIIIBLUE_VIS;
     case GAL_SPECLINES_HBETA:         return GAL_SPECLINES_ANGSTROM_HBETA;
-    case GAL_SPECLINES_HEIIRED:       return GAL_SPECLINES_ANGSTROM_HEIIRED;
+    case GAL_SPECLINES_HEII_VIS:      return GAL_SPECLINES_ANGSTROM_HEII_VIS;
     case GAL_SPECLINES_HGAMMA:        return GAL_SPECLINES_ANGSTROM_HGAMMA;
     case GAL_SPECLINES_HDELTA:        return GAL_SPECLINES_ANGSTROM_HDELTA;
     case GAL_SPECLINES_HEPSILON:      return GAL_SPECLINES_ANGSTROM_HEPSILON;
@@ -181,8 +223,22 @@ gal_speclines_line_angstrom(int linecode)
     case GAL_SPECLINES_CIIIRED:       return GAL_SPECLINES_ANGSTROM_CIIIRED;
     case GAL_SPECLINES_CIII:          return GAL_SPECLINES_ANGSTROM_CIII;
     case GAL_SPECLINES_CIIIBLUE:      return GAL_SPECLINES_ANGSTROM_CIIIBLUE;
-    case GAL_SPECLINES_HEIIBLUE:      return GAL_SPECLINES_ANGSTROM_HEIIBLUE;
+    case GAL_SPECLINES_SiIIIRED:      return GAL_SPECLINES_ANGSTROM_SiIIIRED;
+    case GAL_SPECLINES_SiIII:         return GAL_SPECLINES_ANGSTROM_SiIII;
+    case GAL_SPECLINES_SiIIIBLUE:     return GAL_SPECLINES_ANGSTROM_SiIIIBLUE;
+    case GAL_SPECLINES_OIIIRED_UV:    return GAL_SPECLINES_ANGSTROM_OIIIRED_UV;
+    case GAL_SPECLINES_OIII_UV:       return GAL_SPECLINES_ANGSTROM_OIII_UV;
+    case GAL_SPECLINES_OIIIBLUE_UV:   return GAL_SPECLINES_ANGSTROM_OIIIBLUE_UV;
+    case GAL_SPECLINES_HEII_UV:       return GAL_SPECLINES_ANGSTROM_HEII_UV;
+    case GAL_SPECLINES_CIVRED:        return GAL_SPECLINES_ANGSTROM_CIVRED;
+    case GAL_SPECLINES_CIV:           return GAL_SPECLINES_ANGSTROM_CIV;
+    case GAL_SPECLINES_CIVBLUE:       return GAL_SPECLINES_ANGSTROM_CIVBLUE;
+    case GAL_SPECLINES_NV:            return GAL_SPECLINES_ANGSTROM_NV;
     case GAL_SPECLINES_LYALPHA:       return GAL_SPECLINES_ANGSTROM_LYALPHA;
+    case GAL_SPECLINES_LYBETA:        return GAL_SPECLINES_ANGSTROM_LYBETA;
+    case GAL_SPECLINES_LYGAMMA:       return GAL_SPECLINES_ANGSTROM_LYGAMMA;
+    case GAL_SPECLINES_LYDELTA:       return GAL_SPECLINES_ANGSTROM_LYDELTA;
+    case GAL_SPECLINES_LYEPSILON:     return GAL_SPECLINES_ANGSTROM_LYEPSILON;
     case GAL_SPECLINES_LYLIMIT:       return GAL_SPECLINES_ANGSTROM_LYLIMIT;
     default:
       error(EXIT_FAILURE, 0, "%s: '%d' not recognized line identifier",
